==> pyedb-0.54.0.tar.gz: pyedb-0.54.0/src/pyedb/grpc/database/simulation_setup/sweep_data.py <==
# Copyright (C) 2023 - 2024 ANSYS, Inc. and/or its affiliates.
# SPDX-License-Identifier: MIT
#
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

from ansys.edb.core.simulation_setup.simulation_setup import (
    Distribution as GrpcDistribution,
)
from ansys.edb.core.simulation_setup.simulation_setup import (
    FrequencyData as GrpcFrequencyData,
)
from ansys.edb.core.simulation_setup.simulation_setup import SweepData as GrpcSweepData


class SweepData(GrpcSweepData):
    """Frequency sweep data class."""

    def __init__(self, pedb, name, distribution, start_f, end_f, step, edb_object=None):
        super().__init__(
            name=name,
            frequency_data=GrpcFrequencyData(
                distribution=GrpcDistribution[distribution], start_f=start_f, end_f=end_f, step=step
            ),
        )
        self._edb_object = edb_object
        self._pedb = pedb

==> pyedb-0.61.0.tar.gz: pyedb-0.61.0/src/pyedb/grpc/database/simulation_setup/sweep_data.py <==
# Copyright (C) 2023 - 2025 ANSYS, Inc. and/or its affiliates.
# SPDX-License-Identifier: MIT
#
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

from ansys.edb.core.simulation_setup.simulation_setup import (
    Distribution as GrpcDistribution,
    FrequencyData as GrpcFrequencyData,
    SweepData as GrpcSweepData,
)


class SweepData(GrpcSweepData):
    """Frequency sweep data class."""

    def __init__(self, pedb, name, distribution, start_f, end_f, step, edb_object=None):
        super().__init__(
            name=name,
            frequency_data=GrpcFrequencyData(
                distribution=GrpcDistribution[distribution], start_f=start_f, end_f=end_f, step=step
            ),
        )
        self._edb_object = edb_object
        self._pedb = pedb
